@@ -41,7 +41,6 @@
 #' @param region borders to display as a region code specified as a
 #'   two-character ccTLD ("top-level domain") value, see
 #'   \url{http://en.wikipedia.org/wiki/List_of_Internet_top-level_domains#Country_code_top-level_domains}
-#'
 #' @param markers data.frame with first column longitude, second column
 #'   latitude, for which google markers should be embedded in the map image, or
 #'   character string to be passed directly to api
@@ -81,11 +80,11 @@
 #' df <- d(n=50,r=3,a=.3)
 #' map <- get_googlemap(markers = df, path = df,, scale = 2)
 #' ggmap(map)
-#' ggmap(map, fullpage = TRUE) +
+#' ggmap(map, extent = "device") +
 #'   geom_point(aes(x = lon, y = lat), data = df, size = 3, colour = "black") +
 #'   geom_path(aes(x = lon, y = lat), data = df)
 #'
-#' gc <- geocode("waco, texas")
+#' gc <- geocode("waco, texas", source = "google")
 #' center <- as.numeric(gc)
 #' ggmap(get_googlemap(center = center, color = "bw", scale = 2), extent = "device")
 #'
@@ -153,9 +152,8 @@ get_googlemap <- function(
     stopifnot(all(is.numeric(size)) && all(size == round(size)) && all(size > 0))
   }
 
-  if("scale" %in% argsgiven){
-    stopifnot(scale %in% c(1,2,4))
-  }
+  if("scale" %in% argsgiven) stopifnot(scale %in% c(1,2,4))
+
 
   # format arg checked by match.arg
 
@@ -255,7 +253,7 @@ get_googlemap <- function(
   }
   zoom_url <- paste0("zoom=", zoom)
   size_url <- paste0("size=", paste(size, collapse="x"))
-  scale_url <- if(!missing(scale)){ paste0("scale=", scale) } else { "" }
+  scale_url <- paste0("scale=", scale)
   format_url <- if(!missing(format) && format != "png8"){ paste0("format=", format) } else { "" }
   maptype_url <- paste0("maptype=", maptype, sep = "")
   language_url <- if(!missing(language)){ paste0("language=", language) } else { "" }
@@ -334,6 +332,7 @@ get_googlemap <- function(
   message(paste0("Map from URL : ", url))
 
   map <- readPNG(tmp)
+  map <- aperm(map, c(2, 1, 3))
 
   # format file
   if(color == "color"){
@@ -343,10 +342,22 @@ get_googlemap <- function(
   	map <- gray(.30 * map[,,1] + .59 * map[,,2] + .11 * map[,,3])
   	dim(map) <- mapd[1:2]
   }
+  map <- matrix(map, nrow = scale*size[2], ncol = scale*size[1])
   class(map) <- c("ggmap","raster")
+  # plot(map)
 
   # map spatial info
   if(is.character(center)) center <- as.numeric(geocode(center, source = "google"))
+
+  llList <- RgoogleMaps::LatLon2XY(lon = center[1], lat = center[2], zoom = zoom)
+  ll <- XY2LonLat(
+    X = llList[[c(1,1)]], Y = llList[[c(1,2)]], zoom = zoom,
+    x = llList[[c(2,1)]], y = llList[[c(2,2)]]
+  )
+
+  urList <- RgoogleMaps::LatLon2XY(lon = center[1], lat = center[2], zoom = zoom)
+  ur <- XY2LonLat(llList[[c(1,1)]], llList[[c(1,2)]], zoom, llList[[c(2,1)]], llList[[c(2,2)]])
+
   ll <- XY2LatLon(
     list(lat = center[2], lon = center[1], zoom = zoom),
     -size[1]/2 + 0.5,
@@ -368,7 +379,7 @@ get_googlemap <- function(
   attr(map, "zoom")    <- zoom
 
   # transpose
-  out <- t(map)
+  out <- map # t(map)
 
   # archive map for future use
   fileNameCenter <- as.character(center)
@@ -458,9 +469,7 @@ get_googlemap_checkargs <- function(args){
     }
 
     # scale arg
-    if("scale" %in% argsgiven){
-      stopifnot(scale %in% c(1,2,4))
-    }
+    if("scale" %in% argsgiven) stopifnot(scale %in% c(1,2,4))
 
     # format arg checked by match.arg
 
